<?php
namespace Controller;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Service;
use Util;


class TaskStatus extends \Generated\Controller\TaskStatus {

	private $taskOptionsService;

	public function __construct(Manager $dataSourceManager, Service\TaskOptions $taskOptionsService){
		$this->taskOptionsService = $taskOptionsService;
		parent::__construct($dataSourceManager);
	}

	public function find(Request\Filter $request, Response $response){
        $filters = $request->getFilterCriteria()->getConditions();
		$dataSet = $this->taskOptionsService->findTaskStatus($filters);
		$response->addDataSet(new DataSet('taskstatus', $dataSet));
	}

	public function save(Request\DataSet $request, Response $response){
		$parameter      = $request->getDataSet()->getRows();
		$parameter      = $parameter[0];
        $control        = empty($parameter['CONTROL']) ? null : $parameter['CONTROL'];
        $label          = empty($parameter['LABEL']) ? null : $parameter['LABEL'];
        $isTask         = empty($parameter['IS_TASK']) ? 'N' : $parameter['IS_TASK'];
        $isIssue        = empty($parameter['IS_ISSUE']) ? 'N' : $parameter['IS_ISSUE'];
        $taskType       = empty($parameter['TASK_TYPE']) ? null : $parameter['TASK_TYPE'];
        $idTaskStatus   = empty($parameter['ID']) ? null : $parameter['ID'];
        $isInitial      = empty($parameter['IS_INITIAL']) ? null : $parameter['IS_INITIAL'];
        $usedInTask     = empty($parameter['USED_IN_TASK']) ? null : $parameter['USED_IN_TASK'];
        $usedInIssue    = empty($parameter['USED_IN_ISSUE']) ? null : $parameter['USED_IN_ISSUE'];
		try{
			if(empty($idTaskStatus)){
				$dataSet = $this->taskOptionsService->createTaskStatus($control,$label,$isIssue,$taskType,$isInitial,$isTask,$usedInTask,$usedInIssue);
				$response->addNotification(new Response\Notification(\Util\Messages::SUC_SUCCESSFUL_CREATED));
				$response->addDataSet(new DataSet('taskstatus', $dataSet));
			} else {
				$this->taskOptionsService->updateTaskStatus($idTaskStatus,$control,$label,$isIssue,$taskType,$isInitial,$isTask,$usedInTask,$usedInIssue);
				$response->addNotification(new Response\Notification(\Util\Messages::SUC_SUCCESSFUL_UPDATED));
			}
		} catch(\Exception $e){
			$response->addMessage(new Response\Message(\Util\Messages::ERR_NOT_SUCCESSFUL_SAVED_EXPLANATION.$e->getMessage()));
		}
	}

	public function delete(Request\DataSet $request, Response $response) {
		parent::delete($request, $response);
        Util\Utilities::treatResponseError($response, 'Não foi possível excluir o status selecionado, pois alguma tarefa
        está utilizando-o.');
    }

}
