/*
 Tecnisa - Tecnologia em Informtica

 Nome: LISTA_ALMOXLOCAL_PRODUTO

  Descrio:
  Funo para detectar listar os almoxarfados e localizao parametrizados para o produto

 Criao:
 14/04/2017 - Marina Amaral
*/
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LISTA_ALMOXLOCAL_PRODUTO'
             AND TYPE = 'TF'
             AND U.UID = O.UID
             AND U.NAME = USER)
DROP FUNCTION LISTA_ALMOXLOCAL_PRODUTO
GO

CREATE FUNCTION LISTA_ALMOXLOCAL_PRODUTO
(
 @P_CDFILIAL      VARCHAR(4),
 @P_CDPRODINICIAL VARCHAR(6),
 @P_CDPRODFINAL   VARCHAR(6)
)
returns @ALMOXLOCALPROD_TABLE table
(
 CDFILIAL        VARCHAR(04),
 NMFILIAL        VARCHAR(30),
 CDPRODUTO       VARCHAR(10),
 CDARVPROD       VARCHAR(20),
 NMPRODUTO       VARCHAR(50),
 IDENTIFICADOR   VARCHAR(10),
 CDALMOXARIFADO  VARCHAR(06),
 NMALMOXARIFADO  VARCHAR(30),
 CDLOCALIZACAO   VARCHAR(06),
 NMLOCALIZACAO   VARCHAR(30)
)
AS
BEGIN
   DECLARE @V_NMFILIAL      VARCHAR(30);
   DECLARE @V_CDALMOXARIFE  VARCHAR(06);
   DECLARE @V_DSALMOXARIFE  VARCHAR(30);
   DECLARE @V_CDLOCALESTOQ  VARCHAR(06);
   DECLARE @V_DSLOCALESTOQ  VARCHAR(30);
   DECLARE @V_PRODUTOS_CDPRODUTO VARCHAR(10);
   DECLARE @V_PRODUTOS_CDARVPROD VARCHAR(20);
   DECLARE @V_PRODUTOS_NMPRODUTO VARCHAR(50);

   SELECT @V_NMFILIAL = MAX(NMFILIAL)
     FROM FILIAL
    WHERE CDFILIAL = @P_CDFILIAL;

   DECLARE C_PRODUTOS CURSOR FOR
                      SELECT CDPRODUTO, CDARVPROD, NMPRODUTO
                        FROM PRODUTO
                       WHERE CDARVPROD BETWEEN @P_CDPRODINICIAL AND @P_CDPRODFINAL
                         AND CDNVPRODUTO = (SELECT MAX(CDNVPRODUTO)
                                              FROM PRODUTO);
   OPEN C_PRODUTOS;
   FETCH NEXT FROM C_PRODUTOS INTO @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO;
   WHILE (@@FETCH_STATUS = 0) BEGIN

      -- Almoxarifado/Localizao Matria-Prima / Insumos para Produo
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXINSPR), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCALINSPR), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXINSPR = L.CDALMOXARIFE AND
                            PF.CDLOCALINSPR = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXINSPR IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXINSPR = A.CDALMOXARIFE;

      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'INSPR', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Produto Semiacabado
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXPRSEMACA) , @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCALPRSEMACA)  , @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXPRSEMACA = L.CDALMOXARIFE AND
                            PF.CDLOCALPRSEMACA = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXPRSEMACA  IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXPRSEMACA  = A.CDALMOXARIFE;

      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'SEMACA', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Matria-Prima Piloto / Insumos para a Produo
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXINSPRPIL), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCALINSPRPIL), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXINSPRPIL   = L.CDALMOXARIFE AND
                            PF.CDLOCALINSPRPIL   = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXINSPRPIL   IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXINSPRPIL   = A.CDALMOXARIFE;

      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'PRPIL', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Matria-Prima/ Insumos Em Produo
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXPROD), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCPROD), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXPROD = L.CDALMOXARIFE AND
                            PF.CDLOCPROD = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXPROD        IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXPROD        = A.CDALMOXARIFE;

      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'PROD', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Matria-Prima Piloto / Insumos Em Produo
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXPRODPL), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCPRODPL), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXPRODPL = L.CDALMOXARIFE AND
                            PF.CDLOCPRODPL = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXPRODPL           IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXPRODPL           = A.CDALMOXARIFE;

      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'PRODPL', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Produto Acabado
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXPRACA), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCALPRACA), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXPRACA = L.CDALMOXARIFE AND
                            PF.CDLOCALPRACA = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXPRACA    IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXPRACA          = A.CDALMOXARIFE;

      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'PRACA', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Expedio / Reserva de Pedidos
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXPRCLI), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCALPRCLI), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXPRCLI = L.CDALMOXARIFE AND
                            PF.CDLOCALPRCLI = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXPRCLI    IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXPRCLI          = A.CDALMOXARIFE;

      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'PRCLI', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Quarentena - Matria-Prima / Insumos
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXARIFE), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCALESTOQ), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXARIFE = L.CDALMOXARIFE AND
                            PF.CDLOCALESTOQ = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXARIFE    IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXARIFE = A.CDALMOXARIFE;

      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'MPQUAR', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Quarentena - Matria-Prima Produto Piloto
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXQUAMPPIL), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCALQUAMPPIL), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXQUAMPPIL = L.CDALMOXARIFE AND
                            PF.CDLOCALQUAMPPIL = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXQUAMPPIL     IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXQUAMPPIL = A.CDALMOXARIFE;
      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'QUAMPPIL', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Quarentena - Produto Acabado
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXQUAR), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCALQUAR), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXQUAR = L.CDALMOXARIFE AND
                            PF.CDLOCALQUAR = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXQUAR     IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXQUAR = A.CDALMOXARIFE;

      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'QUAR', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Produtos Reprovados
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOXREPROV), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCALREPROV), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOXREPROV = L.CDALMOXARIFE AND
                            PF.CDLOCALREPROV = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOXREPROV     IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOXREPROV           = A.CDALMOXARIFE;
      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'REPROV', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;

      -- Almoxarifado/Localizao Conferncia de Pesagem
      SELECT @V_CDALMOXARIFE = MAX(PF.CDALMOCONFPESMP), @V_DSALMOXARIFE = MAX(A.DSALMOXARIFE), @V_CDLOCALESTOQ = MAX(PF.CDLOCACONFPESMP), @V_DSLOCALESTOQ = MAX(L.DSLOCALESTOQ)
        FROM PRODFILI PF LEFT JOIN LOCALESTOQUE L
                         ON PF.CDFILIAL = L.CDFILIAL AND
                            PF.CDALMOCONFPESMP = L.CDALMOXARIFE AND
                            PF.CDLOCACONFPESMP = L.CDLOCALESTOQ,
             ALMOXARIFADO A
       WHERE PF.CDALMOCONFPESMP    IS NOT NULL
         AND PF.CDFILIAL = @P_CDFILIAL
         AND PF.CDPRODUTO = @V_PRODUTOS_CDPRODUTO
         AND PF.CDFILIAL = A.CDFILIAL
         AND PF.CDALMOCONFPESMP           = A.CDALMOXARIFE;
      IF (@V_CDALMOXARIFE IS NOT NULL) BEGIN
         INSERT INTO @ALMOXLOCALPROD_TABLE
         (CDFILIAL , NMFILIAL , CDPRODUTO , CDARVPROD , NMPRODUTO,
          IDENTIFICADOR, CDALMOXARIFADO, NMALMOXARIFADO, CDLOCALIZACAO, NMLOCALIZACAO)
          VALUES
         (@P_CDFILIAL, @V_NMFILIAL, @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO,
          'CPE', @V_CDALMOXARIFE, @V_DSALMOXARIFE, @V_CDLOCALESTOQ, @V_DSLOCALESTOQ);
      END;
      FETCH NEXT FROM C_PRODUTOS INTO @V_PRODUTOS_CDPRODUTO, @V_PRODUTOS_CDARVPROD, @V_PRODUTOS_NMPRODUTO;
   END;
   CLOSE C_PRODUTOS;
   DEALLOCATE C_PRODUTOS;
   RETURN;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LISTA_ALMOXLOCAL_PRODUTO','0.00.000';
GO